@@ -1,4 +1,4 @@
-
+### AB: classe creee le 4/5/2011
 #---------------------------------------------------------------------------
 # CLASS "keymatrix" and its METHODS
 # An S4 class to represent an elementary key matrix in the planor package
@@ -10,12 +10,25 @@
 # NOTE
 # An object of class designkey or keyring is a collection of keymatrix objects
 #---------------------------------------------------------------------------
-setClass("keymatrix",
-         contains=c("matrix"),
-         representation(p="numeric"))
+setClass("keymatrix", slots=c(.Data="matrix", p="numeric"))
+setMethod("initialize",
+          "keymatrix",
+          function(.Object, .Data, p) {
+            storage.mode(.Data) <- "integer"
+            .Object@.Data <- .Data
+            .Object@p <- p
+            .Object
+          })
+validitykeymatrix <- function(object) {
+  if (storage.mode(object@.Data) == "integer") TRUE
+  else
+    paste(" keymatrix not integer")
+}
+setValidity("keymatrix",  validitykeymatrix)
+
 ##--------------------------------------------------------------------------
-
-
+### HM, March 2011  ==> new elementary function
+### HM, March 2011  ==> distinction between treatment and block effects
 # "summary.keymatrix"
 # Summarises the main properties of a single key matrix, by displaying the key matrix, the factorial effects confounded with the mean, and the weight profiles of the effects confounded with the mean
 #
@@ -39,7 +52,7 @@ setClass("keymatrix",
 
 summary.keymatrix <- function(object, fact, block,
                               show="dtbw", save="k", ...){
-
+### HM, 5 may 2011
   ## missing arguments
   if(missing(fact)){ fact <- seq(ncol(object)) }
   if(missing(block)){ block <- rep(FALSE, ncol(object)) }
@@ -82,17 +95,27 @@ summary.keymatrix <- function(object, fact, block,
   ## b.Hgen is  a matrix with 0 column
   if (ncol(b.Hgen) == 0) {
     warning("Regular matrix: no confounding\n")
-    
+    ### AB 15/06/2015
     save <- sub('w', '', save) 
   } else {
+    
     b.H <- subgroup.basep(b.Hgen,p)
+    
     ## b.H is a matrix
     b.H <- weightorder.basep(b.H, p, fact, block)
+    
     ## printing
     ## no printing of b.H for the moment
-    
+    ### printgmat( b.H )
     ## selection of the columns free from block effects
+    
+###  AJOUT AB: 7/7/15
+  if (all(block ==FALSE))
+    selectCol <- rep(TRUE, ncol(b.H))
+  else
+    ### FIN AJOUT AB
     selectCol <- apply( b.H[block, , drop=FALSE], 2, sum ) == 0
+    
     ## PLANORlibsk ne modifie rien, ne fait qu'écrire
     if (grepl('t', show, ignore.case=TRUE)) {
       cat("TREATMENT EFFECTS CONFOUNDED WITH THE MEAN\n")
@@ -100,7 +123,7 @@ summary.keymatrix <- function(object, fact, block,
         H.show <- matrix(b.H[,selectCol], nrow=nrow(b.H))
          .Call("PLANORlibsk", as.integer(nrow(H.show)),
             as.integer(ncol(H.show)),
-            H.show,
+            as.integer(H.show),
             as.character(lib),
             as.integer(maxprint))
         cat("\n")
@@ -124,8 +147,8 @@ summary.keymatrix <- function(object, fact, block,
     ## C. Design key kernels
     if (grepl('w', show, ignore.case=TRUE) ||
         grepl('w', save, ignore.case=TRUE)) {
-
-
+### HM, March 2011 ==> pour le moment, le calcul de $blc.weight et
+###    de $blc.pseudoweight ne servent a rien
     Wprint <- rbind(attributes(b.H)$trt.weight,
                     attributes(b.H)$trt.pseudoweight,
                     attributes(b.H)$blc.weight,
@@ -170,7 +193,7 @@ summary.keymatrix <- function(object, fact, block,
   } # end grepl on show and save
     cat("\n")
   } ## end  else Hgen with 0 column
-
+###  return(Wprint)
     if (grepl('k', save, ignore.case=TRUE)) {
       sortie$k <- b.Hgen
     }
@@ -196,8 +219,8 @@ summary.keymatrix <- function(object, fact, block,
 
 
 ##-----------------------------------------------------
-
-
+### HM, March 2011  ==> new elementary function
+### HM, March 2011  ==> distinction between treatment and block effects
 # "alias.keymatrix"
 # Summarises the aliasing properties of a single key matrix
 # ARGUMENTS
@@ -219,8 +242,8 @@ summary.keymatrix <- function(object, fact, block,
 # ---------------------------------------------
 
 alias.keymatrix <- function(object, model,  fact, block, ...){
-  
-  
+  ### AB: le 1ier argu doit s'appeler 'object' pour etre en conformite
+  ### avec la definition de la fonction generique
   ## missing arguments
   if(missing(fact)){ fact <- seq(ncol(object)) }
   if(missing(block)){ block <- rep(FALSE, ncol(object)) }
@@ -254,24 +277,24 @@ alias.keymatrix <- function(object, model,  fact, block, ...){
     blc.log[j] <- any( block[nonzero.model.j] )
     ## normalization of the first non-zero element of the image vectors, if needed
     nonzero.j <- b.images.mat[,j] != 0
-
+### HM, 29/5/11
     if( any(nonzero.j) & (p!=2) ){
-
+### first.ind[j] <- seq(nrow(model))[nonzero.j][1]
       first.ind[j] <- seq(nrow(b.images.mat))[nonzero.j][1]
       first.val[j] <- b.images.mat[first.ind[j], j]
       ## Raw calculation of the inverses modulo p
-
-
-
-
+###      if(p==2){
+###        first.inv[j] <- first.val[j]
+###      }
+###      else{
       inv <- 0
       inv <- .C("PLANORinv", as.integer(p),
                 as.integer(first.val[j]),
                 inv= as.integer(inv))$inv
       first.inv[j] <- inv
-
+###      }
         b.images.mat[, j] <- (first.inv[j] * b.images.mat[, j]) %%p
-
+### HM, 29/5/11 : line below added to get the correct aliasing coefficients
         b.model.full[, j] <- (first.inv[j] * b.model.full[, j]) %%p
     } ## end of the normalization
   } ## end of the loop on j
